==> jboss-test-1.0.3.GA-sources.jar: org/jboss/ant/taskdefs/server/ConfigManagerTask.java <==
/*
* JBoss, Home of Professional Open Source
* Copyright 2005, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.ant.taskdefs.server;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;
import org.jboss.test.util.server.Server;
import org.jboss.test.util.server.ServerManager;

/**
 * A ConfigManagerTask.  Delegates to the Server manager.
 * 
 * @author <a href="ryan.campbell@jboss.com">Ryan Campbell</a>
 * @version $Revision: 56504 $
 */
public class ConfigManagerTask extends Task
{
   /** The key for the project reference **/
   protected static final String MANAGER_REF = "serverManager";

   ServerManager manager = null;

   /**
    * Create a new ConfigManagerTask.
    * 
    * 
    */
   public ConfigManagerTask()
   {
       manager = new ServerManager();
   }
   
   /**
    * Create a server manager using the specified configuration.
    */
   public void execute() throws BuildException
   {
      if (getProject().getReference(MANAGER_REF) == null)
      {
         getProject().addReference(MANAGER_REF, manager);   
      }
   }

   /**
    * Add a server.
    * 
    * @param server the server
    */
   public void addServer(Server server)
   {
      manager.addServer(server);
   }

   /** 
    * JAVA_HOME to start jboss with.
    * @param javaHome
    */
   public void setJavaHome(String javaHome)
   {
      manager.setJavaHome(javaHome);
   }

   /**
    * JBoss dist to start.
    * @param jbossHome
    */
   public void setJbossHome(String jbossHome)
   {
      manager.setJbossHome(jbossHome);
   }

   /**
    * JVM command to use default is "java"
    * @param jvm
    */
   public void setJvm(String jvm)
   {
      manager.setJvm(jvm);
   }
   
   /**
    * The UDP group to pass to org.jboss.Main using
    * the -u option.
    * 
    * @param udpGroup the udp group
    */
   public void setUdpGroup(String udpGroup)
   {
      manager.setUdpGroup(udpGroup);
   }
}

==> jboss-test-1.1.0.GA-sources.jar: org/jboss/ant/taskdefs/server/ConfigManagerTask.java <==
/*
* JBoss, Home of Professional Open Source
* Copyright 2005, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.ant.taskdefs.server;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;
import org.jboss.jbossas.servermanager.Server;
import org.jboss.jbossas.servermanager.ServerManager;
/**
 * A ConfigManagerTask.  Delegates to the Server manager.
 * 
 * @author <a href="ryan.campbell@jboss.com">Ryan Campbell</a>
 * @version $Revision: 70715 $
 */
public class ConfigManagerTask extends Task
{
   /** The key for the project reference **/
   protected static final String MANAGER_REF = "serverManager";

   static ServerManager manager = null;

   /**
    * Create a new ConfigManagerTask.
    * 
    * 
    */
   public ConfigManagerTask()
   {
      if (ConfigManagerTask.manager == null)
      {
         ConfigManagerTask.manager = new ServerManager();
      }
   }
   
   /**
    * Create a server manager using the specified configuration.
    */
   public void execute() throws BuildException
   {
      if (getProject().getReference(ConfigManagerTask.MANAGER_REF)==null)
      {
         getProject().addReference(MANAGER_REF, ConfigManagerTask.manager);
      }
   }

   /**
    * Add a server.
    * 
    * @param server the server
    */
   public void addServer(Server server)
   {
      ConfigManagerTask.manager.addServer(server);
   }

   /** 
    * JAVA_HOME to start jboss with.
    * @param javaHome
    */
   public void setJavaHome(String javaHome)
   {
      ConfigManagerTask.manager.setJavaHome(javaHome);
   }

   /**
    * JBoss dist to start.
    * @param jbossHome
    */
   public void setJbossHome(String jbossHome)
   {
      ConfigManagerTask.manager.setJbossHome(jbossHome);
   }

   /**
    * JVM command to use default is "java"
    * @param jvm
    */
   public void setJvm(String jvm)
   {
      ConfigManagerTask.manager.setJvm(jvm);
   }
   
   /**
    * The UDP group to pass to org.jboss.Main using
    * the -u option.
    * 
    * @param udpGroup the udp group
    */
   public void setUdpGroup(String udpGroup)
   {
      ConfigManagerTask.manager.setUdpGroup(udpGroup);
   }
}
